
//
// ftimer.c  by Ian Ollmann
//
// Copyright  2003 Apple Computer. All Rights Reserved. 
//
// A simple fast timer for use benchmarking functions that take
// around a microsecond to complete. Call startclock() to start
// the clock running. Call stopclock( (double*) result) to find
// out how much time has elapsed since that time. 
//
// The time difference between start and stop is returned in seconds.
//	
// This timer is not thead safe. It should only be used in one 
// thread at a time. 
//

#include <mach/mach_time.h>

u_int64_t 	startTime;

void startclock( void )
{
	startTime = mach_absolute_time();
}

stopclock( double *time )
{
	u_int64_t 			endTime = mach_absolute_time();
	u_int64_t 			difference = endTime - startTime;
	mach_timebase_info_data_t	timebase;
	kern_return_t			err;

	memset( &timebase, 0, sizeof( timebase ));

	err = mach_timebase_info( &timebase );
	if( 0 != err )
	{
		*time = -1.0/0.0;	//-Inf
		return;
	}

	*time = 1e-9 * (double) timebase.numer * (double) difference / (double) timebase.denom;
}
